==> kmymoney_5.1.3.orig.tar.xz: kmymoney-5.1.3/kmymoney/plugins/onlinetasks/sepa/kmymoney-sepaorders.json.cmake <==
{
    "KMyMoney": {
        "OnlineTask": {
            "Editors": [
                {
                    "Name": "SEPA Order",
                    "Name[de]": "Sepa Überweisung",
                    "OnlineTaskIds": [
                        "org.kmymoney.creditTransfer.sepa"
                    ],
                    "PluginKeyword": "sepaCreditTransferUi"
                }
            ],
            "Iids": [
                "org.kmymoney.creditTransfer.sepa"
            ],
            "PluginKeyword": "sepaOnlineTasks"
        },
        "StoragePlugin": {
            "Iid": "org.kmymoney.creditTransfer.sepa.sqlStoragePlugin",
            "PluginKeyword": "sepaSqlStoragePlugin"
        }
    },
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian David",
                "Name[ca@valencia]": "Christian David",
                "Name[ca]": "Christian David",
                "Name[cs]": "Christian David",
                "Name[de]": "Christian David",
                "Name[en_GB]": "Christian David",
                "Name[es]": "Christian David",
                "Name[et]": "Christian David",
                "Name[eu]": "Christian David",
                "Name[fi]": "Christian David",
                "Name[fr]": "Christian David",
                "Name[gl]": "Christian David",
                "Name[ia]": "Christian David",
                "Name[it]": "Christian David",
                "Name[ko]": "Christian David",
                "Name[nl]": "Christian David",
                "Name[pl]": "Christian David",
                "Name[pt]": "Christian David",
                "Name[pt_BR]": "Christian David",
                "Name[ru]": "Christian David",
                "Name[sk]": "Christian David",
                "Name[sl]": "Christian David",
                "Name[sv]": "Christian David",
                "Name[uk]": "Christian David",
                "Name[x-test]": "xxChristian Davidxx",
                "Name[zh_CN]": "Christian David"
            }
        ],
        "Description": "Order types for single european payment area (SEPA) orders",
        "Description[ca@valencia]": "Tipus d'ordres per a les ordres de l'àrea única europea de pagaments «SEPA» (Single European Payment Area)",
        "Description[ca]": "Tipus d'ordres per a les ordres de l'àrea única europea de pagaments «SEPA» (Single European Payment Area)",
        "Description[en_GB]": "Order types for single European payment area (SEPA) orders",
        "Description[es]": "Tipos de órdenes para la zona única de pagos en euros (SEPA)",
        "Description[et]": "Ühtse euromaksete piirkonna (SEPA) maksekorralduste tüübid",
        "Description[eu]": "SEPArako agindu motak",
        "Description[fi]": "Maksutyypit Euroopan yhtenäismaksualueen (SEPA) maksumääräyksille",
        "Description[fr]": "Types de virements pour les virements SEPA (espace unique de paiement en euros)",
        "Description[gl]": "Tipos das ordes da área europea única de pagos (SEPA)",
        "Description[it]": "Tipi per gli ordini dell'area unica dei pagamenti in euro (SEPA)",
        "Description[ko]": "SEPA(단일유로결제지역) 주문에 대한 주문 형식",
        "Description[nl]": "Opdrachttypen voor enkelvoudige betalingsopdrachten in Europees gebied (SEPA)",
        "Description[pl]": "Rodzaje przelewów dla SEPA",
        "Description[pt]": "Tipos de transferências SEPA (Single European Payment Area)",
        "Description[pt_BR]": "Tipos de ordem para o SEPA (Single European Payment Area)",
        "Description[ru]": "Типы платёжных поручений для единого европейского пространства платежей (SEPA)",
        "Description[sl]": "Plačilni nalogi za enotno evropsko plačilno območje (SEPA)",
        "Description[sv]": "Ordertyp för gemensamma eurobetalningsområdet (SEPA) order",
        "Description[uk]": "Типи векселів для Єдиної європейської системи сплат (SEPA)",
        "Description[x-test]": "xxOrder types for single european payment area (SEPA) ordersxx",
        "Description[zh_CN]": "单一欧元支付区订单类型",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "SEPA orders for online banking",
        "License": "GPLv2+",
        "Name": "SEPA orders",
        "Name[ca@valencia]": "Ordres SEPA",
        "Name[ca]": "Ordres SEPA",
        "Name[de]": "SEPA-Aufträge",
        "Name[en_GB]": "SEPA orders",
        "Name[es]": "Pagos SEPA",
        "Name[et]": "SEPA maksekorraldused",
        "Name[eu]": "SEPA aginduak",
        "Name[fi]": "SEPA-maksut",
        "Name[fr]": "Virements SEPA",
        "Name[gl]": "Ordes SEPA",
        "Name[ia]": "Ordines SEPA",
        "Name[it]": "Ordini SEPA",
        "Name[ko]": "SEPA 주문",
        "Name[nl]": "SEPA-opdrachten",
        "Name[pl]": "Przelewy SEPA",
        "Name[pt]": "Transferências SEPA",
        "Name[pt_BR]": "Ordens SEPA",
        "Name[ru]": "Платёжные поручения SEPA",
        "Name[sk]": "SEPA príkazy",
        "Name[sl]": "Naročila SEPA",
        "Name[sv]": "SEPA-order",
        "Name[uk]": "Векселі SEPA",
        "Name[x-test]": "xxSEPA ordersxx",
        "Name[zh_CN]": "单一欧元支付区订单",
        "ServiceTypes": [
            "KMyMoney/OnlineTask",
            "KMyMoney/OnlineTaskUi",
            "KMyMoney/sqlStoragePlugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.95.tar.xz: kmymoney-5.1.95/kmymoney/plugins/onlinetasks/sepa/kmymoney-sepaorders.json.cmake <==
{
    "KMyMoney": {
        "OnlineTask": {
            "Editors": [
                {
                    "Name": "SEPA Order",
                    "Name[de]": "Sepa Überweisung",
                    "OnlineTaskIds": [
                        "org.kmymoney.creditTransfer.sepa"
                    ]
                }
            ],
            "Iids": [
                "org.kmymoney.creditTransfer.sepa"
            ]
        },
        "StoragePlugin": {
            "Iid": "org.kmymoney.creditTransfer.sepa.sqlStoragePlugin"
        }
    },
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian David",
                "Name[ca@valencia]": "Christian David",
                "Name[ca]": "Christian David",
                "Name[cs]": "Christian David",
                "Name[de]": "Christian David",
                "Name[en_GB]": "Christian David",
                "Name[eo]": "Kristana Davido",
                "Name[es]": "Christian David",
                "Name[et]": "Christian David",
                "Name[eu]": "Christian David",
                "Name[fi]": "Christian David",
                "Name[fr]": "Christian David",
                "Name[gl]": "Christian David",
                "Name[ia]": "Christian David",
                "Name[it]": "Christian David",
                "Name[ka]": "Christian David",
                "Name[ko]": "Christian David",
                "Name[nb]": "Christian David",
                "Name[nl]": "Christian David",
                "Name[pl]": "Christian David",
                "Name[pt]": "Christian David",
                "Name[pt_BR]": "Christian David",
                "Name[ru]": "Christian David",
                "Name[sk]": "Christian David",
                "Name[sl]": "Christian David",
                "Name[sv]": "Christian David",
                "Name[tr]": "Christian David",
                "Name[uk]": "Christian David",
                "Name[x-test]": "xxChristian Davidxx",
                "Name[zh_CN]": "Christian David",
                "Name[zh_TW]": "Christian David"
            }
        ],
        "Description": "Order types for single european payment area (SEPA) orders",
        "Description[ca@valencia]": "Tipus d'ordres per a les ordres de l'àrea única europea de pagaments «SEPA» (Single European Payment Area)",
        "Description[ca]": "Tipus d'ordres per a les ordres de l'àrea única europea de pagaments «SEPA» (Single European Payment Area)",
        "Description[en_GB]": "Order types for single European payment area (SEPA) orders",
        "Description[eo]": "Mendotipoj por mendoj de ununura eŭropa paga areo (SEPA).",
        "Description[es]": "Tipos de órdenes para la zona única de pagos en euros (SEPA)",
        "Description[et]": "Ühtse euromaksete piirkonna (SEPA) maksekorralduste tüübid",
        "Description[eu]": "SEPArako agindu motak",
        "Description[fi]": "Maksutyypit Euroopan yhtenäismaksualueen (SEPA) maksumääräyksille",
        "Description[fr]": "Types de virements pour les virements SEPA (espace unique de paiement en euros)",
        "Description[gl]": "Tipos das ordes da área europea única de pagos (SEPA)",
        "Description[it]": "Tipi per gli ordini dell'area unica dei pagamenti in euro (SEPA)",
        "Description[ka]": "ერთიანი ევროპული გადახდის (SEPA) შეკვეთების ტიპები",
        "Description[ko]": "SEPA(단일유로결제지역) 주문에 대한 주문 형식",
        "Description[nb]": "Ordretyper for SEPA-ordrer",
        "Description[nl]": "Opdrachttypen voor enkelvoudige betalingsopdrachten in Europees gebied (SEPA)",
        "Description[pl]": "Rodzaje przelewów dla SEPA",
        "Description[pt]": "Tipos de transferências SEPA (Single European Payment Area)",
        "Description[pt_BR]": "Tipos de ordem para o SEPA (Single European Payment Area)",
        "Description[ru]": "Типы платёжных поручений для единого европейского пространства платежей (SEPA)",
        "Description[sl]": "Plačilni nalogi za enotno evropsko plačilno območje (SEPA)",
        "Description[sv]": "Ordertyp för gemensamma eurobetalningsområdet (SEPA) order",
        "Description[tr]": "Avrupa tek ödeme bölgesi (SEPA) talimatları için talimat türleri",
        "Description[uk]": "Типи векселів для Єдиної європейської системи сплат (SEPA)",
        "Description[x-test]": "xxOrder types for single european payment area (SEPA) ordersxx",
        "Description[zh_CN]": "单一欧元支付区订单类型",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "SEPA orders for online banking",
        "License": "GPLv2+",
        "Name": "SEPA orders",
        "Name[ca@valencia]": "Ordres SEPA",
        "Name[ca]": "Ordres SEPA",
        "Name[de]": "SEPA-Aufträge",
        "Name[en_GB]": "SEPA orders",
        "Name[eo]": "SEPA ordonoj",
        "Name[es]": "Pagos SEPA",
        "Name[et]": "SEPA maksekorraldused",
        "Name[eu]": "SEPA aginduak",
        "Name[fi]": "SEPA-maksut",
        "Name[fr]": "Virements SEPA",
        "Name[gl]": "Ordes SEPA",
        "Name[it]": "Ordini SEPA",
        "Name[ka]": "SEPA შეკვეთები",
        "Name[ko]": "SEPA 주문",
        "Name[nb]": "SEPA-ordrer",
        "Name[nl]": "SEPA-opdrachten",
        "Name[pl]": "Przelewy SEPA",
        "Name[pt]": "Transferências SEPA",
        "Name[pt_BR]": "Ordens SEPA",
        "Name[ru]": "Платёжные поручения SEPA",
        "Name[sk]": "SEPA príkazy",
        "Name[sl]": "Naročila SEPA",
        "Name[sv]": "SEPA-order",
        "Name[tr]": "SEPA talimatları",
        "Name[uk]": "Векселі SEPA",
        "Name[x-test]": "xxSEPA ordersxx",
        "Name[zh_CN]": "单一欧元支付区订单",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
